==> rawtherapee_5.8.orig.tar.xz: rawtherapee-5.8/rtgui/addsetids.h <==
#pragma once

//          UPDATE THE DEFAULT VALUE IN OPTIONS.CC  int babehav[] TOO !!!

enum {
    ADDSET_TC_EXPCOMP,
    ADDSET_TC_BRIGHTNESS,
    ADDSET_TC_BLACKLEVEL,
    ADDSET_TC_CONTRAST,
    ADDSET_SH_HIGHLIGHTS,
    ADDSET_SH_SHADOWS,
    ADDSET_SH_LOCALCONTRAST, // not used anymore
    ADDSET_LC_BRIGHTNESS,
    ADDSET_LC_CONTRAST,
    ADDSET_SHARP_AMOUNT,
    ADDSET_WB_TEMPERATURE,
    ADDSET_WB_GREEN,
    ADDSET_ROTATE_DEGREE,
    ADDSET_DIST_AMOUNT,
    ADDSET_PERSPECTIVE,
    ADDSET_CA,
    ADDSET_VIGN_AMOUNT,
    ADDSET_VIGN_RADIUS,
    ADDSET_VIGN_STRENGTH,
    ADDSET_VIGN_CENTER,
    ADDSET_LC_CHROMATICITY,
    ADDSET_TC_SATURATION,
    ADDSET_TC_HLCOMPAMOUNT,
    ADDSET_TC_HLCOMPTHRESH,
    ADDSET_TC_SHCOMP,
    ADDSET_DIRPYREQ,
    ADDSET_DIRPYRDN_LUMA,
    ADDSET_DIRPYRDN_LUMDET,
    ADDSET_DIRPYRDN_CHROMA,
    ADDSET_DIRPYRDN_CHROMARED,
    ADDSET_DIRPYRDN_CHROMABLUE,
    ADDSET_DIRPYRDN_GAMMA,
    ADDSET_CHMIXER,
    ADDSET_PREPROCESS_GREENEQUIL,
    ADDSET_PREPROCESS_LINEDENOISE,
    ADDSET_RAWCACORR,
    ADDSET_RAWEXPOS_LINEAR,
    ADDSET_RAWEXPOS_BLACKS,
    ADDSET_SHARPENEDGE_AMOUNT,
    ADDSET_SHARPENMICRO_AMOUNT,
    ADDSET_SHARPENEDGE_PASS,
    ADDSET_SHARPENMICRO_UNIFORMITY,
    ADDSET_VIBRANCE_PASTELS,
    ADDSET_VIBRANCE_SATURATED,
    ADDSET_CAT_DEGREE,
    ADDSET_CAT_ADAPTSCENE,
    ADDSET_CAT_ADAPTVIEWING,
    ADDSET_CAT_LIGHT,
    ADDSET_CAT_CHROMA,
    ADDSET_CAT_CONTRAST,
    ADDSET_CAT_RSTPRO,
    ADDSET_CAT_BRIGHT,
    ADDSET_CAT_CONTRAST_Q,
    ADDSET_CAT_CHROMA_S,
    ADDSET_CAT_CHROMA_M,
    ADDSET_CAT_HUE,
    ADDSET_CAT_BADPIX,
    ADDSET_WB_EQUAL,
    ADDSET_GRADIENT_DEGREE,
    ADDSET_GRADIENT_FEATHER,
    ADDSET_GRADIENT_STRENGTH,
    ADDSET_GRADIENT_CENTER,
    ADDSET_PCVIGNETTE_STRENGTH,
    ADDSET_PCVIGNETTE_FEATHER,
    ADDSET_PCVIGNETTE_ROUNDNESS,
    ADDSET_BLACKWHITE_HUES,
    ADDSET_BLACKWHITE_GAMMA,
    ADDSET_DIRPYREQ_THRESHOLD,
    ADDSET_DIRPYREQ_SKINPROTECT,
    ADDSET_COLORTONING_SPLIT,
    ADDSET_COLORTONING_SATTHRESHOLD,
    ADDSET_COLORTONING_SATOPACITY,
    ADDSET_COLORTONING_BALANCE,
    ADDSET_COLORTONING_STRENGTH,
    ADDSET_DIRPYRDN_PASSES,
    ADDSET_RAWFFCLIPCONTROL,
    ADDSET_FILMSIMULATION_STRENGTH,
    ADDSET_WA,
    ADDSET_WA_SKINPROTECT,
    ADDSET_WA_THRR,
    ADDSET_WA_THRRH,
    ADDSET_WA_THRES,
    ADDSET_WA_THRESHOLD,
    ADDSET_WA_THRESHOLD2,
    ADDSET_WA_CHRO,
    ADDSET_WA_CHROMA,
    ADDSET_WA_CONTRAST,
    ADDSET_WA_RESCON,
    ADDSET_WA_RESCONH,
    ADDSET_WA_RESCHRO,
    ADDSET_WA_SKYPROTECT,
    ADDSET_WA_EDGRAD,
    ADDSET_WA_EDGVAL,
    ADDSET_WA_STRENGTH,
    ADDSET_WA_EDGEDETECT,
    ADDSET_WA_EDGEDETECTTHR,
    ADDSET_WA_EDGEDETECTTHR2,
    ADDSET_WA_TMRS,
    ADDSET_WA_GAMMA,
    ADDSET_RETI_STR,
    ADDSET_RETI_NEIGH,
    ADDSET_RETI_LIMD,
    ADDSET_RETI_GAIN,
    ADDSET_RETI_OFFS,
    ADDSET_RETI_VART,
    ADDSET_RETI_GAM,
    ADDSET_RETI_SLO,
    ADDSET_WB_TEMPBIAS,
    ADDSET_SHARP_RADIUS,
    ADDSET_SHARP_DAMPING,
    ADDSET_SHARP_ITER,
    ADDSET_SHARP_EDGETOL,
    ADDSET_SHARP_HALOCTRL,
    ADDSET_RESIZE_SCALE,
    ADDSET_EPD_STRENGTH,
    ADDSET_EPD_GAMMA,
    ADDSET_EPD_EDGESTOPPING,
    ADDSET_EPD_SCALE,
    ADDSET_EPD_REWEIGHTINGITERATES,
    ADDSET_FATTAL_THRESHOLD,
    ADDSET_FATTAL_AMOUNT,
    ADDSET_LOCALCONTRAST_RADIUS,
    ADDSET_LOCALCONTRAST_AMOUNT,
    ADDSET_LOCALCONTRAST_DARKNESS,
    ADDSET_LOCALCONTRAST_LIGHTNESS,
    ADDSET_FATTAL_ANCHOR,
    ADDSET_SHARPENMICRO_CONTRAST,
    ADDSET_SHARP_CONTRAST,
    ADDSET_BAYER_FALSE_COLOR_SUPPRESSION,
    ADDSET_BAYER_ITER,
    ADDSET_BAYER_PS_SMOOTH,
    ADDSET_BAYER_PS_EPERISO,
    ADDSET_BAYER_PS_SIGMA,
    ADDSET_BAYER_DUALDEMOZCONTRAST,
    ADDSET_XTRANS_FALSE_COLOR_SUPPRESSION,
    ADDSET_SOFTLIGHT_STRENGTH,
    ADDSET_DEHAZE_STRENGTH,

    ADDSET_PARAM_NUM // THIS IS USED AS A DELIMITER!!
};

==> rawtherapee_5.9.orig.tar.xz: rawtherapee-5.9/rtgui/addsetids.h <==
#pragma once

//          UPDATE THE DEFAULT VALUE IN OPTIONS.CC  int babehav[] TOO !!!

enum {
    ADDSET_TC_EXPCOMP,
    ADDSET_TC_BRIGHTNESS,
    ADDSET_TC_BLACKLEVEL,
    ADDSET_TC_CONTRAST,
    ADDSET_SH_HIGHLIGHTS,
    ADDSET_SH_SHADOWS,
    ADDSET_SH_LOCALCONTRAST, // not used anymore
    ADDSET_LC_BRIGHTNESS,
    ADDSET_LC_CONTRAST,
    ADDSET_SHARP_AMOUNT,
    ADDSET_WB_TEMPERATURE,
    ADDSET_WB_GREEN,
    ADDSET_ROTATE_DEGREE,
    ADDSET_DIST_AMOUNT,
    ADDSET_PERSPECTIVE,
    ADDSET_PERSP_CAM_ANGLE,
    ADDSET_PERSP_CAM_FOCAL_LENGTH,
    ADDSET_PERSP_CAM_SHIFT,
    ADDSET_PERSP_PROJ_ANGLE,
    ADDSET_PERSP_PROJ_ROTATE,
    ADDSET_PERSP_PROJ_SHIFT,
    ADDSET_CA,
    ADDSET_VIGN_AMOUNT,
    ADDSET_VIGN_RADIUS,
    ADDSET_VIGN_STRENGTH,
    ADDSET_VIGN_CENTER,
    ADDSET_LC_CHROMATICITY,
    ADDSET_TC_SATURATION,
    ADDSET_TC_HLCOMPAMOUNT,
    ADDSET_TC_HLCOMPTHRESH,
    ADDSET_TC_SHCOMP,
    ADDSET_DIRPYREQ,
    ADDSET_DIRPYRDN_LUMA,
    ADDSET_DIRPYRDN_LUMDET,
    ADDSET_DIRPYRDN_CHROMA,
    ADDSET_DIRPYRDN_CHROMARED,
    ADDSET_DIRPYRDN_CHROMABLUE,
    ADDSET_DIRPYRDN_GAMMA,
    ADDSET_CHMIXER,
    ADDSET_PREPROCESS_GREENEQUIL,
    ADDSET_PREPROCESS_LINEDENOISE,
    ADDSET_RAWCACORR,
    ADDSET_RAWEXPOS_LINEAR,
    ADDSET_RAWEXPOS_BLACKS,
    ADDSET_SHARPENEDGE_AMOUNT,
    ADDSET_SHARPENMICRO_AMOUNT,
    ADDSET_SHARPENEDGE_PASS,
    ADDSET_SHARPENMICRO_UNIFORMITY,
    ADDSET_VIBRANCE_PASTELS,
    ADDSET_VIBRANCE_SATURATED,
    ADDSET_CAT_DEGREE,
    ADDSET_CAT_ADAPTSCENE,
    ADDSET_CAT_ADAPTVIEWING,
    ADDSET_CAT_LIGHT,
    ADDSET_CAT_CHROMA,
    ADDSET_CAT_CONTRAST,
    ADDSET_CAT_RSTPRO,
    ADDSET_CAT_BRIGHT,
    ADDSET_CAT_CONTRAST_Q,
    ADDSET_CAT_CHROMA_S,
    ADDSET_CAT_CHROMA_M,
    ADDSET_CAT_HUE,
    ADDSET_CAT_BADPIX,
    ADDSET_WB_EQUAL,
    ADDSET_GRADIENT_DEGREE,
    ADDSET_GRADIENT_FEATHER,
    ADDSET_GRADIENT_STRENGTH,
    ADDSET_GRADIENT_CENTER,
    ADDSET_PCVIGNETTE_STRENGTH,
    ADDSET_PCVIGNETTE_FEATHER,
    ADDSET_PCVIGNETTE_ROUNDNESS,
    ADDSET_BLACKWHITE_HUES,
    ADDSET_BLACKWHITE_GAMMA,
    ADDSET_DIRPYREQ_THRESHOLD,
    ADDSET_DIRPYREQ_SKINPROTECT,
    ADDSET_COLORTONING_SPLIT,
    ADDSET_COLORTONING_SATTHRESHOLD,
    ADDSET_COLORTONING_SATOPACITY,
    ADDSET_COLORTONING_BALANCE,
    ADDSET_COLORTONING_STRENGTH,
    ADDSET_DIRPYRDN_PASSES,
    ADDSET_RAWFFCLIPCONTROL,
    ADDSET_FILMSIMULATION_STRENGTH,
    ADDSET_WA,
    ADDSET_WA_SKINPROTECT,
    ADDSET_WA_THRR,
    ADDSET_WA_THRRH,
    ADDSET_WA_RADIUS,
    ADDSET_WA_THRES,
    ADDSET_WA_THRESHOLD,
    ADDSET_WA_THRESHOLD2,
    ADDSET_WA_CHRO,
    ADDSET_WA_CHROMA,
    ADDSET_WA_CONTRAST,
    ADDSET_WA_RESCON,
    ADDSET_WA_RESCONH,
    ADDSET_WA_RESCHRO,
    ADDSET_WA_SKYPROTECT,
    ADDSET_WA_EDGRAD,
    ADDSET_WA_EDGVAL,
    ADDSET_WA_STRENGTH,
    ADDSET_WA_EDGEDETECT,
    ADDSET_WA_EDGEDETECTTHR,
    ADDSET_WA_EDGEDETECTTHR2,
    ADDSET_WA_TMRS,
    ADDSET_WA_EDGS,
    ADDSET_WA_SCALE,
    ADDSET_WA_GAMMA,
    ADDSET_RETI_STR,
    ADDSET_RETI_NEIGH,
    ADDSET_RETI_LIMD,
    ADDSET_RETI_GAIN,
    ADDSET_RETI_OFFS,
    ADDSET_RETI_VART,
    ADDSET_RETI_GAM,
    ADDSET_RETI_SLO,
    ADDSET_WB_TEMPBIAS,
    ADDSET_SHARP_RADIUS,
    ADDSET_SHARP_DAMPING,
    ADDSET_SHARP_ITER,
    ADDSET_SHARP_EDGETOL,
    ADDSET_SHARP_HALOCTRL,
    ADDSET_RESIZE_SCALE,
    ADDSET_EPD_STRENGTH,
    ADDSET_EPD_GAMMA,
    ADDSET_EPD_EDGESTOPPING,
    ADDSET_EPD_SCALE,
    ADDSET_EPD_REWEIGHTINGITERATES,
    ADDSET_FATTAL_THRESHOLD,
    ADDSET_FATTAL_AMOUNT,
    ADDSET_LOCALCONTRAST_RADIUS,
    ADDSET_LOCALCONTRAST_AMOUNT,
    ADDSET_LOCALCONTRAST_DARKNESS,
    ADDSET_LOCALCONTRAST_LIGHTNESS,
    ADDSET_FATTAL_ANCHOR,
    ADDSET_SHARPENMICRO_CONTRAST,
    ADDSET_SHARP_CONTRAST,
    ADDSET_BAYER_FALSE_COLOR_SUPPRESSION,
    ADDSET_BAYER_ITER,
    ADDSET_BAYER_PS_SMOOTH,
    ADDSET_BAYER_PS_EPERISO,
    ADDSET_BAYER_PS_SIGMA,
    ADDSET_BAYER_DUALDEMOZCONTRAST,
    ADDSET_XTRANS_FALSE_COLOR_SUPPRESSION,
    ADDSET_SOFTLIGHT_STRENGTH,
    ADDSET_DEHAZE_STRENGTH,

    ADDSET_PARAM_NUM // THIS IS USED AS A DELIMITER!!
};
